@@ -24,21 +24,105 @@ template_cache_dir = "cache"
 
 #TODO: Also try for Cisco build here
 
-lookup = TemplateLookup(directories=[resource_path("")],
-                        #module_directory= template_cache_dir,
-                        cache_type='memory',
-                        cache_enabled=True,
-                       )
+def initialise_lookup():
+    lookup = TemplateLookup(directories=[resource_path("")],
+                            #module_directory= template_cache_dir,
+                            cache_type='memory',
+                            cache_enabled=True,
+                           )
 
-try:
-    import autonetkit_cisco # test if can import, if not present will fail and not add to template path
-    cisco_templates = pkg_resources.resource_filename("autonetkit_cisco", "")
-    lookup.directories.append(cisco_templates)
-except ImportError:
-    pass # Cisco ANK not present
+    try:
+        import autonetkit_cisco # test if can import, if not present will fail and not add to template path
+        cisco_templates = pkg_resources.resource_filename("autonetkit_cisco", "")
+        lookup.directories.append(cisco_templates)
+    except ImportError:
+        pass # Cisco ANK not present
+
+    return lookup
+
+#TODO: make lookup initialised once rather than global for module import
+lookup = initialise_lookup()
+
+def format_version_banner():
+    version_banner = "autonetkit_dev"
+    try:
+        import autonetkit_cisco # test if can import, if not present will fail and not add to template path
+    except ImportError:
+        pass
+    else:
+        import autonetkit_cisco.version
+        version_banner = autonetkit_cisco.version.banner()
+        return version_banner
+
+    try:
+        version_banner = ("autonetkit_%s" %
+            pkg_resources.get_distribution("autonetkit").version)
+         #TODO: pick up name automatically
+    except pkg_resources.DistributionNotFound:
+        version_banner = "autonetkit_dev"
+
+    return version_banner
 
 #TODO: make a render class, that caches traversed folders for speed
 
+def render_inline(node, render_template_file, to_memory = True,
+    render_dst_file = None):
+    """Generic rendering of a node attribute rather than the standard location.
+    Needs to be called by render_node.
+    Doesn't support base folders - only single attributes.
+    Note: supports rendering to memory (ie back to nidb rather than file)
+    """
+
+    log.debug("Rendering template %s for %s" % (render_template_file, node))
+    render_template_file #TODO: remove this?
+
+    version_banner= format_version_banner()
+
+    date = time.strftime("%Y-%m-%d %H:%M", time.localtime())
+
+    if render_template_file:
+        try:
+            render_template = lookup.get_template(render_template_file)
+        except SyntaxException, error:
+            log.warning( "Unable to render %s: "
+                "Syntax error in template: %s" % (node, error))
+            return
+
+        if node.render.dst_file:
+            dst_file = os.path.join(render_output_dir, node.render.dst_file)
+            with open( dst_file, 'wb') as dst_fh:
+                try:
+                    dst_fh.write(render_template.render(
+                        node = node,
+                        version_banner = version_banner,
+                        date = date,
+                        ))
+                except KeyError, error:
+                    log.warning( "Unable to render %s:"
+                        " %s not set" % (node, error))
+                except AttributeError, error:
+                    log.warning( "Unable to render %s: %s " % (node, error))
+                    from mako import exceptions
+                    log.warning(exceptions.text_error_template().render())
+                except NameError, error:
+                    log.warning( "Unable to render %s: %s. "
+                        "Check all variables used are defined" % (node, error))
+                except TypeError, error:
+                    log.warning( "Unable to render %s: %s." % (node, error))
+                    from mako import exceptions
+                    log.warning(exceptions.text_error_template().render())
+
+
+        if to_memory:
+# Render directly to NIDB
+            render_output = render_template.render(
+                        node = node,
+                        version_banner = version_banner,
+                        date = date,
+                        )
+
+            return render_output
+
 #TODO: Add support for both src template and src folder (eg for quagga, servers)
 def render_node(node, folder_cache):
     log.debug("Rendering %s" % node)
@@ -53,12 +137,7 @@ def render_node(node, folder_cache):
         #TODO: make sure allows case of just custom render
         return
 
-    try:
-        ank_version = ("autonetkit_%s" %
-            pkg_resources.get_distribution("autonetkit").version)
-         #TODO: pick up name automatically
-    except pkg_resources.DistributionNotFound:
-        ank_version = "autonetkit_dev"
+    version_banner= format_version_banner()
 
     date = time.strftime("%Y-%m-%d %H:%M", time.localtime())
     if render_custom:
@@ -90,7 +169,7 @@ def render_node(node, folder_cache):
                 try:
                     dst_fh.write(render_template.render(
                         node = node,
-                        ank_version = ank_version,
+                        version_banner = version_banner,
                         date = date,
                         ))
                 except KeyError, error:
@@ -113,10 +192,11 @@ def render_node(node, folder_cache):
 # Render directly to NIDB
             node.render.render_output = render_template.render(
                         node = node,
-                        ank_version = ank_version,
+                        version_banner = version_banner,
                         date = date,
                         )
     if render_base:
+        #TODO: remove the folder cache for simplicity: doesn't sufficiently improve speed to warrant complexity
         if render_base in folder_cache:
             src_folder = folder_cache[render_base]['folder']
             fs_mako_templates = folder_cache[render_base]['templates']
@@ -140,7 +220,7 @@ def render_node(node, folder_cache):
                 with open( dst_file, 'wb') as dst_fh:
                     dst_fh.write(mytemplate.render(
                         node = node,
-                        ank_version = ank_version,
+                        version_banner = version_banner,
                         date = date,
                         ))
             return
@@ -207,10 +287,8 @@ def render_topologies(nidb):
         render_topology(topology)
 
 def render_topology(topology):
-    try:
-        ank_version = "autonetkit_%s" % pkg_resources.get_distribution("autonetkit").version #TODO: pick up name automatically
-    except pkg_resources.DistributionNotFound:
-        ank_version = "autonetkit_dev"
+    version_banner= format_version_banner()
+
     date = time.strftime("%Y-%m-%d %H:%M", time.localtime())
     try:
         render_output_dir = topology.render_dst_folder
@@ -251,7 +329,7 @@ def render_topology(topology):
         try:
             dst_fh.write(render_template.render(
                 topology = topology,
-                ank_version = ank_version,
+                version_banner = version_banner,
                 date = date,
                 ))
         except KeyError, error:
